pub struct Query {
pub offset: TextSize,
pub before: Option<PositionInfo>,
pub after: Option<PositionInfo>,
}Fields
offset: TextSizeThe offset the query was made for.
before: Option<PositionInfo>Before the cursor.
after: Option<PositionInfo>After the cursor.
Implementations
Sourceimpl Query
impl Query
Sourcepub fn at(root: &Node, offset: TextSize) -> Self
pub fn at(root: &Node, offset: TextSize) -> Self
Query a DOM root with the given cursor offset.
Returns None if the position is out of range.
Panics
Panics if the DOM was not entirely constructed from a syntax tree (e.g. if a node has no associated syntax element). Also panics if the given DOM node is not root.
Also the given offset must be within the tree.
Sourceimpl Query
impl Query
pub fn in_table_header(&self) -> bool
pub fn in_table_array_header(&self) -> bool
pub fn header_key(&self) -> Option<SyntaxNode>
pub fn entry_key(&self) -> Option<SyntaxNode>
pub fn entry_value(&self) -> Option<SyntaxNode>
pub fn parent_table_or_array_table(&self, root: &Node) -> (Keys, Node)
pub fn empty_line(&self) -> bool
pub fn in_entry_keys(&self) -> bool
pub fn entry_has_eq(&self) -> bool
pub fn in_entry_value(&self) -> bool
pub fn is_single_quote_value(&self) -> bool
pub fn is_inline(&self) -> bool
pub fn in_inline_table(&self) -> bool
pub fn in_array(&self) -> bool
pub fn entry_keys(&self) -> Keys
pub fn header_keys(&self) -> Keys
pub fn dom_node(&self) -> Option<&(Keys, Node)>